# Drupal test theme (not sandboxed)

* https://www.drupal.org/project/theme_test_not_sandboxed
* https://git.drupalcode.org/project/theme_test_not_sandboxed

## Release workflow

My normal publishing workflow is the following:

* develop locally until it feels ready for a first release
* publish on git host (only once)
  * login on git host (e. g. codeberg.org or github.com)
  * create empty repository
  * if not setup already: add SSH key, configure local `~/.ssh/config` and KeePassXC as ssh agent
  * initial git setup:

```bash
git remote add origin git@git.drupal.org:project/theme_test_not_sandboxed.git
git push -u origin main
```

* publish on packagist.org (only once)
  * login
  * publish new project
  * setup webhook on git host for automatic updates

Now my setup is ready and fully automated (except tests/CI setup).

Publishing a new release is fast and simple:

* change something
* tag a new release
* push it to git host

```bash
git add theme_test_not_sandboxed.info.yml
git commit -m "added theme.info.yml"
git tag -a 0.1.1 -m "added theme.info.yml"
git push --follow-tags
```

Done.

I can run `composer update` in my website project and the new version is downloaded automatically.

Drupal needs a lot of extra steps. Just tagging with git and publishing doesn't trigger a new release. So it's different from the default composer behaviour. Tagging (or branching) via git and publishing is still required. So all steps from above (except publishing on packagist.org) are neccessary. Afterwards I have to manually do the following steps - for every new release:

* login on drupal.org
* go to https://www.drupal.org/project/theme_test_not_sandboxed
* click "Edit" in horizontal nav
* click "Releases" in horizontal sub nav
* click "Add new release"
* Select version
  * --> now some info text pops up (with a bad recommendation - see notes section below)
  * click checkbox "This release will not be covered for security advisories"
* click "Next" button
* optional: enter text for "Release notes", "Short description" and click a checkbox under "Release type"
  * --> __Remember:__ No markdown support! Copy/Paste from `CHANGELOG.md` may cause broken markup --> requires manual editing of code blocks and links
* double check after clicking on "Preview" button
* click "Save" button
* wait a few minutes until the package is created

I don't like it. Since my Drupal project is already set up with composer, I can skip the whole "publish on drupal.org" step and everything just works.

## Notes

* Release naming conventions: https://www.drupal.org/node/1015226
* Creating a project release: https://www.drupal.org/docs/develop/git/git-for-drupal-project-maintainers/creating-a-project-release
* TODO: Automated testing: https://www.drupal.org/docs/develop/managing-a-drupalorg-theme-module-or-distribution-project/maintainership/automated-testing
* Overview "Managing a drupal.org theme, module, or distribution project": https://www.drupal.org/docs/develop/managing-a-drupalorg-theme-module-or-distribution-project

### bad advice on re-tagging

During the release process, right after selecting the current git tag, some info text becomes visible. It has this line:

> Before clicking Next, the Git tag can be deleted or moved. It can not be modified after clicking Next.

This is a bad advice. The tag is already online and should not be changed. Create a new tag instead. See also https://git-scm.com/docs/git-tag#_on_re_tagging for a more verbose explanation.

Another page, where deleting a published tag is adviced: https://www.drupal.org/docs/develop/git/git-for-drupal-project-maintainers/creating-a-project-release#s-deleting-a-tagbranch

### Why `@dev` doesn't work with composer

Using the default branch `main` doesn't work with Drupal. The branch __must__ be named with a version string. So in theory, renaming `main` to `0.x` should work to either automatically generate a dev release or to be able to manually set a branch as dev release.

https://www.drupal.org/docs/develop/git/git-for-drupal-project-maintainers/moving-from-a-master-to-a-major-version-branch

### Thoughts on why docs are confusing and everything is complicated

I have a strong feeling, that the docs are written with moving from legacy systems to Gitlab in mind. Because I started to learn Drupal with v10, I don't know anything about processes from decades ago. The whole part of coming from different places with different default processes is missing in the docs. To understand Drupal I have to change my mental model. I have to unlearn things.

Restructuring the docs might help. Instead of reading possibilities how branches may be named, a better structure may be:

1. Are you new and are already familiar with git and composer? Than read a few lines with current best practices.
  * No `main` branch! Create `0.x` branch instead. Using the same development branch for all future versions and just using git tags for releases is not possible.
  * When introducing breaking changes, create a new branch `1.x` and make this the default one. This also makes it easier to support outdated versions with security fixes.
  * General differences between drupal.org and packagist.org
2. Older user? Than scroll down and read the long text with all edge cases and upgrade steps from legecy systems.
